.. AuthorizeMe documentation master file, created by
   sphinx-quickstart on Mon Aug 17 12:47:46 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to AuthorizeMe documentation!
=====================================

AuthorizeMe is a simple authorization library that can be used with
or without any Python web framework.

Contents:

.. toctree::
   :maxdepth: 2

   tutorial
   api
   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

